@@ -9,6 +9,7 @@ from click import Abort
 
 from recce import event
 from recce.artifact import (
+    delete_dbt_artifacts,
     download_dbt_artifacts,
     upload_artifacts_to_session,
     upload_dbt_artifacts,
@@ -66,6 +67,75 @@ def create_state_loader(review_mode, cloud_mode, state_file, cloud_options):
         exit(1)
 
 
+def patch_derived_args(args):
+    """
+    Patch derived args based on other args.
+    """
+    if args.get("session_id") or args.get("share_url"):
+        args["cloud"] = True
+        args["review"] = True
+
+
+def create_state_loader_by_args(state_file=None, **kwargs):
+    """
+    Create a state loader based on CLI arguments.
+
+    This function handles the cloud options logic that is shared between
+    server and mcp-server commands.
+
+    Args:
+        state_file: Optional path to state file
+        **kwargs: CLI arguments including api_token, cloud, review, session_id, share_url, etc.
+
+    Returns:
+        state_loader: The created state loader instance
+    """
+    from rich.console import Console
+
+    console = Console()
+
+    api_token = kwargs.get("api_token")
+    is_review = kwargs.get("review", False)
+    is_cloud = kwargs.get("cloud", False)
+    cloud_options = None
+
+    # Handle share_url and session_id
+    share_url = kwargs.get("share_url")
+    session_id = kwargs.get("session_id")
+
+    if share_url:
+        share_id = share_url.split("/")[-1]
+        if not share_id:
+            console.print("[[red]Error[/red]] Invalid share URL format.")
+            exit(1)
+
+    if is_cloud:
+        # Cloud mode
+        if share_url:
+            cloud_options = {
+                "host": kwargs.get("state_file_host"),
+                "api_token": api_token,
+                "share_id": share_id,
+            }
+        elif session_id:
+            cloud_options = {
+                "host": kwargs.get("state_file_host"),
+                "api_token": api_token,
+                "session_id": session_id,
+            }
+        else:
+            cloud_options = {
+                "host": kwargs.get("state_file_host"),
+                "github_token": kwargs.get("cloud_token"),
+                "password": kwargs.get("password"),
+            }
+
+    # Create state loader
+    state_loader = create_state_loader(is_review, is_cloud, state_file, cloud_options)
+
+    return state_loader
+
+
 def handle_debug_flag(**kwargs):
     if kwargs.get("debug"):
         import logging
@@ -74,6 +144,14 @@ def handle_debug_flag(**kwargs):
         ch.setFormatter(CustomFormatter())
         logging.basicConfig(handlers=[ch], level=logging.DEBUG)
 
+        # Explicitly set uvicorn logger to DEBUG level
+        uvicorn_logger = logging.getLogger("uvicorn")
+        uvicorn_logger.setLevel(logging.DEBUG)
+
+        # Set all child loggers to DEBUG as well
+        for handler in uvicorn_logger.handlers:
+            handler.setLevel(logging.DEBUG)
+
 
 def add_options(options):
     def _add_options(func):
@@ -145,7 +223,10 @@ recce_cloud_options = [
 
 recce_cloud_auth_options = [
     click.option(
-        "--api-token", help="The personal token generated by Recce Cloud.", type=click.STRING, envvar="RECCE_API_TOKEN"
+        "--api-token",
+        help="The personal token generated by Recce Cloud.",
+        type=click.STRING,
+        envvar="RECCE_API_TOKEN",
     )
 ]
 
@@ -397,18 +478,23 @@ def diff(sql, primary_keys: List[str] = None, keep_shape: bool = False, keep_equ
 @click.option("--host", default="localhost", show_default=True, help="The host to bind to.")
 @click.option("--port", default=8000, show_default=True, help="The port to bind to.", type=int)
 @click.option("--lifetime", default=0, show_default=True, help="The lifetime of the server in seconds.", type=int)
+@click.option(
+    "--idle-timeout",
+    default=0,
+    show_default=True,
+    help="The idle timeout in seconds. If 0, idle timeout is disabled. Maximum value is capped by lifetime.",
+    type=int,
+)
 @click.option("--review", is_flag=True, help="Open the state file in the review mode.")
 @click.option("--single-env", is_flag=True, help="Launch in single environment mode directly.")
-@click.option(
-    "--api-token", help="The personal token generated by Recce Cloud.", type=click.STRING, envvar="RECCE_API_TOKEN"
-)
 @add_options(dbt_related_options)
 @add_options(sqlmesh_related_options)
 @add_options(recce_options)
 @add_options(recce_dbt_artifact_dir_options)
 @add_options(recce_cloud_options)
+@add_options(recce_cloud_auth_options)
 @add_options(recce_hidden_options)
-def server(host, port, lifetime, state_file=None, **kwargs):
+def server(host, port, lifetime, idle_timeout=0, state_file=None, **kwargs):
     """
     Launch the recce server
 
@@ -444,6 +530,8 @@ def server(host, port, lifetime, state_file=None, **kwargs):
     RecceConfig(config_file=kwargs.get("config"))
 
     handle_debug_flag(**kwargs)
+    patch_derived_args(kwargs)
+
     server_mode = kwargs.get("mode") if kwargs.get("mode") else RecceServerMode.server
     is_review = kwargs.get("review", False)
     is_cloud = kwargs.get("cloud", False)
@@ -454,10 +542,11 @@ def server(host, port, lifetime, state_file=None, **kwargs):
         "read_only": False,
     }
     console = Console()
-    cloud_options = None
 
+    # Prepare API token
     try:
         api_token = prepare_api_token(**kwargs)
+        kwargs["api_token"] = api_token
     except RecceConfigException:
         show_invalid_api_token_message()
         exit(1)
@@ -465,41 +554,11 @@ def server(host, port, lifetime, state_file=None, **kwargs):
         "api_token": api_token,
     }
 
-    share_url = kwargs.get("share_url")
-    session_id = kwargs.get("session_id")
-    if share_url:
-        share_id = share_url.split("/")[-1]
-        if not share_id:
-            console.print("[[red]Error[/red]] Invalid share URL format.")
-            exit(1)
-
-    if is_cloud:
-        # Cloud mode
-        if share_url:
-            is_review = kwargs["review"] = True
-            cloud_options = {
-                "host": kwargs.get("state_file_host"),
-                "api_token": api_token,
-                "share_id": share_id,
-            }
-        elif session_id:
-            is_review = kwargs["review"] = True
-            cloud_options = {
-                "host": kwargs.get("state_file_host"),
-                "api_token": api_token,
-                "session_id": session_id,
-            }
-        else:
-            cloud_options = {
-                "host": kwargs.get("state_file_host"),
-                "github_token": kwargs.get("cloud_token"),
-                "password": kwargs.get("password"),
-            }
-    else:
-        # Check Single Environment Onboarding Mode if the review mode is False
+    # Check Single Environment Onboarding Mode if not in cloud mode and not in review mode
+    if not is_cloud and not is_review:
         project_dir_path = Path(kwargs.get("project_dir") or "./")
         target_base_path = project_dir_path.joinpath(Path(kwargs.get("target_base_path", "target-base")))
-        if not target_base_path.is_dir() and not is_review:
+        if not target_base_path.is_dir():
             # Mark as single env onboarding mode if user provides the target-path only
             flag["single_env_onboarding"] = True
             flag["show_relaunch_hint"] = True
@@ -520,7 +579,8 @@ def server(host, port, lifetime, state_file=None, **kwargs):
     # Onboarding State logic update here
     update_onboarding_state(api_token, flag.get("single_env_onboarding"))
 
-    state_loader = create_state_loader(is_review, is_cloud, state_file, cloud_options)
+    # Create state loader using shared function
+    state_loader = create_state_loader_by_args(state_file, **kwargs)
 
     if not state_loader.verify():
         error, hint = state_loader.error_and_hint
@@ -562,6 +622,22 @@ def server(host, port, lifetime, state_file=None, **kwargs):
     else:
         console.rule("Recce Server")
 
+    # Validate idle_timeout: cap at lifetime if it exceeds lifetime
+    if idle_timeout > 0:
+        # If lifetime is set (> 0) and idle_timeout exceeds it, cap to lifetime
+        if lifetime > 0 and idle_timeout > lifetime:
+            effective_idle_timeout = lifetime
+            console.print(
+                f"[[yellow]Warning[/yellow]] idle_timeout ({idle_timeout}s) exceeds lifetime ({lifetime}s). "
+                f"Capping idle_timeout to {effective_idle_timeout}s."
+            )
+        else:
+            # Use idle_timeout as-is (either lifetime is 0, or idle_timeout <= lifetime)
+            effective_idle_timeout = idle_timeout
+    else:
+        # idle_timeout is 0 or negative, disable idle timeout
+        effective_idle_timeout = 0
+
     state = AppState(
         command=server_mode,
         state_loader=state_loader,
@@ -569,7 +645,10 @@ def server(host, port, lifetime, state_file=None, **kwargs):
         flag=flag,
         auth_options=auth_options,
         lifetime=lifetime,
+        idle_timeout=effective_idle_timeout,
         share_url=kwargs.get("share_url"),
+        organization_name=os.environ.get("RECCE_SESSION_ORGANIZATION_NAME"),
+        web_url=os.environ.get("RECCE_CLOUD_WEB_URL"),
     )
     app.state = state
 
@@ -1183,8 +1262,58 @@ def download_base_artifacts(**kwargs):
     return _download_artifacts(branch, cloud_token, console, kwargs, password, target_path)
 
 
+@cloud.command(cls=TrackCommand)
+@click.option("--cloud-token", help="The GitHub token used by Recce Cloud.", type=click.STRING, envvar="GITHUB_TOKEN")
+@click.option(
+    "--branch",
+    "-b",
+    help="The branch to delete artifacts from.",
+    type=click.STRING,
+    envvar="GITHUB_HEAD_REF",
+    default=current_branch(),
+    show_default=True,
+)
+@click.option("--force", "-f", help="Bypasses the confirmation prompt. Delete the artifacts directly.", is_flag=True)
+@add_options(recce_options)
+def delete_artifacts(**kwargs):
+    """
+    Delete the dbt artifacts from cloud
+
+    Delete the dbt artifacts (metadata.json, catalog.json) from Recce Cloud for the given branch.
+    This will permanently remove the artifacts from the cloud storage.
+
+    By default, the artifacts are deleted from the current branch. You can specify the branch using the --branch option.
+    """
+    from rich.console import Console
+
+    console = Console()
+    cloud_token = kwargs.get("cloud_token")
+    branch = kwargs.get("branch")
+    force = kwargs.get("force", False)
+
+    if not force:
+        if not click.confirm(f'Do you want to delete artifacts from branch "{branch}"?'):
+            console.print("Deletion cancelled.")
+            return 0
+
+    try:
+        delete_dbt_artifacts(branch=branch, token=cloud_token, debug=kwargs.get("debug", False))
+        console.print(f"[[green]Success[/green]] Artifacts deleted from branch: {branch}")
+        return 0
+    except click.exceptions.Abort:
+        pass
+    except RecceCloudException as e:
+        console.print("[[red]Error[/red]] Failed to delete the dbt artifacts from cloud.")
+        console.print(f"Reason: {e.reason}")
+        exit(1)
+    except Exception as e:
+        console.print("[[red]Error[/red]] Failed to delete the dbt artifacts from cloud.")
+        console.print(f"Reason: {e}")
+        exit(1)
+
+
 @cloud.command(cls=TrackCommand, name="list-organizations")
-@click.option("--api-token", help="The Recce Cloud API token.", type=click.STRING, envvar="RECCE_CLOUD_API_TOKEN")
+@click.option("--api-token", help="The Recce Cloud API token.", type=click.STRING, envvar="RECCE_API_TOKEN")
 @add_options(recce_options)
 def list_organizations(**kwargs):
     """
@@ -1240,7 +1369,7 @@ def list_organizations(**kwargs):
     type=click.STRING,
     envvar="RECCE_ORGANIZATION_ID",
 )
-@click.option("--api-token", help="The Recce Cloud API token.", type=click.STRING, envvar="RECCE_CLOUD_API_TOKEN")
+@click.option("--api-token", help="The Recce Cloud API token.", type=click.STRING, envvar="RECCE_API_TOKEN")
 @add_options(recce_options)
 def list_projects(**kwargs):
     """
@@ -1322,7 +1451,7 @@ def list_projects(**kwargs):
     type=click.STRING,
     envvar="RECCE_PROJECT_ID",
 )
-@click.option("--api-token", help="The Recce Cloud API token.", type=click.STRING, envvar="RECCE_CLOUD_API_TOKEN")
+@click.option("--api-token", help="The Recce Cloud API token.", type=click.STRING, envvar="RECCE_API_TOKEN")
 @add_options(recce_options)
 def list_sessions(**kwargs):
     """
@@ -1433,7 +1562,10 @@ def artifact(**kwargs):
 @cli.command(cls=TrackCommand)
 @click.argument("state_file", type=click.Path(exists=True))
 @click.option(
-    "--api-token", help="The personal token generated by Recce Cloud.", type=click.STRING, envvar="RECCE_API_TOKEN"
+    "--api-token",
+    help="The personal token generated by Recce Cloud.",
+    type=click.STRING,
+    envvar="RECCE_API_TOKEN",
 )
 def share(state_file, **kwargs):
     """
@@ -1598,5 +1730,106 @@ def read_only(ctx, state_file=None, **kwargs):
     ctx.invoke(server, state_file=state_file, **kwargs)
 
 
+@cli.command(cls=TrackCommand)
+@click.option("--sse", is_flag=True, default=False, help="Start in HTTP/SSE mode instead of stdio mode")
+@click.option("--host", default="localhost", help="Host to bind to in SSE mode (default: localhost)")
+@click.option("--port", default=8000, type=int, help="Port to bind to in SSE mode (default: 8000)")
+@add_options(dbt_related_options)
+@add_options(sqlmesh_related_options)
+@add_options(recce_options)
+@add_options(recce_dbt_artifact_dir_options)
+@add_options(recce_cloud_options)
+@add_options(recce_cloud_auth_options)
+@add_options(recce_hidden_options)
+def mcp_server(sse, host, port, **kwargs):
+    """
+    [Experiment] Start the Recce MCP (Model Context Protocol) server
+
+    The MCP server provides an interface for AI assistants and tools to interact
+    with Recce's data validation capabilities. By default, it uses stdio for
+    communication. Use --sse to enable HTTP/Server-Sent Events mode instead.
+
+    Available tools:
+    - get_lineage_diff: Get lineage differences between environments
+    - row_count_diff: Compare row counts between environments
+    - query: Execute SQL queries with dbt templating
+    - query_diff: Compare query results between environments
+    - profile_diff: Generate statistical profiles and compare
+
+    Examples:\n
+
+    \b
+    # Start the MCP server in stdio mode (default)
+    recce mcp-server
+
+    \b
+    # Start in HTTP/SSE mode on default port 8000
+    recce mcp-server --sse
+
+    \b
+    # Start in HTTP/SSE mode with custom host and port
+    recce mcp-server --sse --host 0.0.0.0 --port 9000
+
+    \b
+    # Start with custom dbt configuration
+    recce mcp-server --target prod --project-dir ./my_project
+
+    SSE Connection URL (when using --sse): http://<host>:<port>/sse
+    """
+    from rich.console import Console
+
+    console = Console()
+    try:
+        # Import here to avoid import errors if mcp is not installed
+        from recce.mcp_server import run_mcp_server
+    except ImportError as e:
+        console.print(f"[[red]Error[/red]] Failed to import MCP server: {e}")
+        console.print(r"Please install the MCP package: pip install 'recce\[mcp]'")
+        exit(1)
+
+    # Initialize Recce Config
+    RecceConfig(config_file=kwargs.get("config"))
+
+    handle_debug_flag(**kwargs)
+    patch_derived_args(kwargs)
+
+    # Prepare API token
+    try:
+        api_token = prepare_api_token(**kwargs)
+        kwargs["api_token"] = api_token
+    except RecceConfigException:
+        show_invalid_api_token_message()
+        exit(1)
+
+    # Create state loader using shared function (if cloud mode is enabled)
+    is_cloud = kwargs.get("cloud", False)
+    if is_cloud:
+        state_loader = create_state_loader_by_args(None, **kwargs)
+        kwargs["state_loader"] = state_loader
+
+    try:
+        if sse:
+            console.print(f"Starting Recce MCP Server in HTTP/SSE mode on {host}:{port}...")
+            console.print(f"SSE endpoint: http://{host}:{port}/sse")
+            console.print("Available tools: get_lineage_diff, row_count_diff, query, query_diff, profile_diff")
+        else:
+            console.print("Starting Recce MCP Server in stdio mode...")
+            console.print("Available tools: get_lineage_diff, row_count_diff, query, query_diff, profile_diff")
+
+        # Run the server (stdio or SSE based on --sse flag)
+        asyncio.run(run_mcp_server(sse=sse, host=host, port=port, **kwargs))
+    except (asyncio.CancelledError, KeyboardInterrupt):
+        # Graceful shutdown (e.g., Ctrl+C)
+        console.print("[yellow]MCP Server interrupted[/yellow]")
+        exit(0)
+    except Exception as e:
+        console.print(f"[[red]Error[/red]] Failed to start MCP server: {e}")
+        if kwargs.get("debug"):
+            import traceback
+
+            traceback.print_exc()
+        exit(1)
+
+
 if __name__ == "__main__":
     cli()
